Flow API
========

The main interface for constructing workflows is the :obj:`Flow` object.

:obj:`Flow` objects contain :obj:`Job` and other :obj:`Flow` objects to execute.
Flows also contain useful functions for modifying and visualising the connectivity
of jobs within them.

.. currentmodule:: jobflow.core.flow

.. autoclass:: Flow
   :noindex:
   :members:
   :show-inheritance:
